#!/usr/bin/env sh

set -o errexit
set -o pipefail
set -o nounset

source ci/stack_env.sh

# Cleaning patches in case one has a different hash
${STACK_LOCATION}/spack/bin/spack \
    --color always \
    -e ${environment} \
    clean -m

${STACK_LOCATION}/spack/bin/spack \
    --color always \
    -e ${environment} install \
    --log-file ${CI_PROJECT_DIR}/spack-install-${environment}.xml \
    --log-format junit \
    --only-concrete \
    --fail-fast \
    --show-log-on-error

${STACK_LOCATION}/spack/bin/spack \
    --color always \
    -e ${environment} \
    find -vl | tee spack-find-${environment}-${stack}.log

${STACK_LOCATION}/spack/bin/spack \
    --color always \
    -e ${environment} \
    buildcache create \
    --update-index \
    --key ${GPG_KEY_ID} \
    ${MOUNT_POINT}/buildcache

echo "Checking ${STACK_CONFIG_PATH}/mark_explicit_${environment} for spec to mark explicit"
if [ -e ${STACK_CONFIG_PATH}/mark_explicit_${environment} ]
then
    while read -r spec
    do
        echo "Mark ${spec} as explicit"
        ${STACK_LOCATION}/spack/bin/spack \
            --color always -d \
            -e ${environment} \
            mark \
            --explicit \
            ${spec}
    done <<< $(cat ${STACK_CONFIG_PATH}/mark_explicit_${environment} )
fi

${STACK_LOCATION}/spack/bin/spack \
    --color always \
    -e ${environment} \
    module lmod refresh \
    --delete-tree \
    --yes | tee spack-modules-${environment}-${stack}.log
